@@ -1,9 +1,9 @@
-# $Id: Split.pm,v 0.09 2003/12/29 18:18:21 st.schubiger Exp $
+#
+# $Id: Split.pm,v 0.1 2003/12/29 22:52:30 st.schubiger Exp $
 
 package Dir::Split;
 
-BEGIN { use 5.6.1; }
-
+use 5.6.1;
 use strict;
 use warnings;
 
@@ -12,18 +12,19 @@ use File::Copy 'cp';
 use File::Path;
 use File::Spec;
 
-our ($scl_source_dir_ref,
+our (%f_names,
+     $scl_source_dir_ref,
      $scl_target_dir_ref,
      $sub_dir_ident,
      $sub_dir_f_sort,
      $suffix_l,
      $suffix_sep);
 
-our $VERSION = 0.09;
+our $VERSION = 0.1;
 
 =head1 NAME
 
-Dir::Split - Split the files of a directory to subdirectories
+Dir::Split - Split the files of a directory to subdirectories.
 
 =head1 SYNOPSIS
 
@@ -61,7 +62,7 @@ Dir::Split - Split the files of a directory to subdirectories
 
 =head1 DESCRIPTION
 
-Dir::Split moves files from a source directory to numbered subdirectories within
+C<Dir::Split> moves files from a source directory to numbered subdirectories within
 a target directory.
 
 =head1 METHODS
@@ -72,7 +73,7 @@ Object constructor.
 
  $dir = Dir::Split->new (\%options);
 
-%options contains the options that will affect the splitting process.
+C<%options> contains the options that will influence the splitting process.
 
  %options = ( verbose =>   0,
 
@@ -87,20 +88,24 @@ Object constructor.
               },
  );
 
-verbose sets the verbosity (see table VERBOSITY MODES below); if enabled,
+C<verbose> sets the verbosity (see table VERBOSITY MODES below); if enabled,
 mkpath will output the pathes on creating subdirectories.
 
-sub_dir => identifier will affect the prefix of each subdirectory.
-sub_dir => file_limit sets the limit of files per each subdirectory.
-sub_dir => file_sort defines the sorting order of files
+C<sub_dir/identifier> will affect the prefix of each subdirectory.
+C<sub_dir/file_limit> sets the limit of files per each subdirectory.
+C<sub_dir/file_sort> defines the sorting order of files
 (see table SORT MODES below).
 
-suffix => separator contains the string that separates the prefix (identifier)
-from the suffix. suffix => length is an non-floating-point integer that sets
+C<suffix/separator> contains the string that separates the prefix (identifier)
+from the suffix. C<suffix/length> is an non-floating-point integer that sets
 the amount of zeros to be added to the subdirectory numbering.
-suffix => continue_num defines whether the numbering shall be continued
+C<suffix/continue_num> defines whether the numbering shall be continued
 where it previously stopped or start at 1 (see table CONTINUE NUMBERING MODES below).
 
+Differing identifiers or separators do affect the numbering e.g. systm-0001 does
+not equal system-0001, system_0001 does not equal system-0001. C<file_limit>, C<file_sort>
+and C<separator> options have no influence on decisions whether the numbering shall be coninued.
+
   VERBOSITY MODES
     0  disabled
     1  enabled
@@ -116,7 +121,8 @@ where it previously stopped or start at 1 (see table CONTINUE NUMBERING MODES be
 =cut
 
 sub new {
-    my ($class, $hsh_opt_ref) = @_;
+    my ($package, $hsh_opt_ref) = @_;
+    my $class = ref ($package) || $package;
     my $self = Dir::Split::_set_var ($hsh_opt_ref);
     bless $self, $class;
 }
@@ -149,9 +155,9 @@ Split the files of the source directory to subdirectories.
 
  $files_moved = $dir->split (\$source_dir, \$target_dir);
 
-$source_dir specifies the source directory.
+C<$source_dir> specifies the source directory.
 
-$target_dir specifies the target directory.
+C<$target_dir> specifies the target directory.
 
 Returns the amount of files that have been successfully moved;
 if none, it will return undef.
@@ -164,7 +170,11 @@ sub split {
     croak q~Invalid arguments: split (\$source_dir, \$target_dir)~
       unless (ref $scl_source_dir_ref eq 'SCALAR') && (ref $scl_target_dir_ref eq 'SCALAR');
 
-    my ($sub_dir_f_limit,
+    my (@files,
+        $path_full,
+        $ret_f_moved,
+        $sub_dir_f_limit,
+        $suffix,
         $suffix_cont_num,
         $verbose_mode);
     STRING_VAR: {
@@ -177,15 +187,14 @@ sub split {
         $suffix_cont_num = $self->{'suffix'}{'continue_num'};
     }
 
-    my (@files, $ret_moved, $suffix);
-    $self->_eval_files (\@files);
+    $self->_eval_files (\@files, \%f_names);
     if ($suffix_cont_num eq 'y') {
         $self->_eval_suffix_highest_num (\$suffix);
     }
     $self->_eval_suffix_sum_up (\$suffix);
 
     for (; @files; $suffix++) {
-        # mk subdir
+        # create subdir
         my $path = File::Spec->catfile($$scl_target_dir_ref,
           "$sub_dir_ident$suffix_sep$suffix");
         unless (mkpath $path, $verbose_mode) {
@@ -194,13 +203,17 @@ sub split {
         # cp & rm files
         for (my $i = 0; $i < $sub_dir_f_limit; $i++) {
             last unless my $file = shift @files;
-            cp ($file, $path) or croak qq~Could not copy file $file to subdir $path: $!~;
+            # obtain case-sensitive filename
+            $path_full = File::Spec->catfile($path, $f_names{$file});
+            # cat absolute file path
+            $file = File::Spec->catfile($$scl_source_dir_ref, $file);
+            cp ($file, $path_full) or croak qq~Could not copy file $file to subdir $path_full: $!~;
             unlink ($file) or croak qq~Could not remove file $file: $!~;
-            $ret_moved++;
+            $ret_f_moved++;
         }
     }
 
-    return $ret_moved ? $ret_moved : undef;
+    return $ret_f_moved ? $ret_f_moved : undef;
 }
 
 #
@@ -213,22 +226,30 @@ sub split {
 #
 
 sub _eval_files {
-    my ($self, $arr_files_ref) = @_;
+    my ($self, $arr_files_ref, $hsh_f_names_ref) = @_;
 
     # fetch source files
     opendir D, $$scl_source_dir_ref or
       croak qq~Could not open source dir $$scl_source_dir_ref for read-access: $!~;
-    @$arr_files_ref = grep { !/^\./ } readdir D;
-    closedir D or croak qq~Could not close source dir $$scl_source_dir_ref: $!~;
-
-    # ignore exist. dirs
     @$arr_files_ref =
+      # ignore exist. dirs
       grep { ! opendir E, File::Spec->catfile($$scl_source_dir_ref, $_) }
-      @$arr_files_ref; closedir E;
+      # skip . ..  
+      grep { !/^\./ } 
+      readdir D;
+    closedir D or croak qq~Could not close source dir $$scl_source_dir_ref: $!~;
+    no warnings; if (telldir E == 0) { closedir E } use warnings;
+
+    # if files are to be sorted, preserve filenames
+    # in hash with their lowercased filenames as keys.
+    if ($sub_dir_f_sort eq '+' || $sub_dir_f_sort eq '-') {
+        foreach (@$arr_files_ref) {
+            $$hsh_f_names_ref{lc($_)} = $_;
+        }
+        # lowercase filenames
+        @$arr_files_ref = map { lc } @$arr_files_ref;
+    }
 
-    # if files are to be sorted, lowercase filenames
-    #@$arr_files_ref = map { lc } @$arr_files_ref if $sub_dir_f_sort eq '+'
-     # || $sub_dir_f_sort eq '-';
     # ascending sort order
     if ($sub_dir_f_sort eq '+') {
         @$arr_files_ref = sort @$arr_files_ref;
@@ -236,9 +257,6 @@ sub _eval_files {
     elsif ($sub_dir_f_sort eq '-') {
         @$arr_files_ref = reverse @$arr_files_ref;
     }
-    # map absolute file paths
-    @$arr_files_ref = map { File::Spec->catfile($$scl_source_dir_ref, $_) }
-      @$arr_files_ref;
 }
 
 #
@@ -255,13 +273,13 @@ sub _eval_suffix_highest_num {
     # fetch target dirs
     opendir D, $$scl_target_dir_ref or
       croak qq~Could not open target dir $$scl_target_dir_ref for read-access: $!~;
-    my @dirs = grep { !/^\./ } readdir D;
-    closedir D or croak qq~Could not close target dir $$scl_target_dir_ref: $!~;
-
-    # ignore exist. files
-    @dirs =
+    my @dirs =
+      # ignore exist. files
       grep { opendir E, File::Spec->catfile($$scl_target_dir_ref, $_) }
-      @dirs; closedir E;
+      # skip . .. 
+      grep { !/^\./ } 
+      readdir D;
+    closedir D or croak qq~Could not close target dir $$scl_target_dir_ref: $!~;
 
     # surpress warnings
     $$scl_suffix_ref = 0;
@@ -269,13 +287,14 @@ sub _eval_suffix_highest_num {
     foreach (@dirs) {
         # extract exist. identifier (prefix)
         $_ =~ s/(.+?)$sep(.*)/$1/;
-        # supplied identifier matches existing one
+        # supplied identifier matches exist. one
         if ($sub_dir_ident eq $_) {
             # increase suffix to highest number
             if ($2 > $$scl_suffix_ref) { $$scl_suffix_ref = $2 }
         }
     }
-    $$scl_suffix_ref++; # suffix + 1 - avoid collisions with curr. subdirs
+    # suffix + 1 - avoid collisions with exist. subdirs
+    $$scl_suffix_ref++;
 }
 
 #
@@ -289,7 +308,7 @@ sub _eval_suffix_highest_num {
 sub _eval_suffix_sum_up {
     my ($self, $scl_suffix_ref) = @_;
 
-    # suffix length too low or to big
+    # suffix length too small or too big
     if (length ($$scl_suffix_ref) < $suffix_l
       || length ($$scl_suffix_ref) > $suffix_l) {
         my $format = "%0.$suffix_l" . 'd';
